@@ -512,6 +512,7 @@ fill_place_from_entry (const char   *key,
                 if (g_str_equal (key, "icon")) {
 	                GFile *file = g_file_new_for_uri (value);
 	                GIcon *icon = g_file_icon_new (file);
+	                g_object_unref (file);
 
 	                g_object_set (G_OBJECT (place), "icon", icon, NULL);
 	                g_object_unref (icon);
@@ -531,8 +532,7 @@ node_free_func (GNode    *node,
 	return FALSE;
 }
 
-#define N_ATTRS 8
-static const char const *attributes[8] = {
+static const char const *attributes[] = {
 	"country",
 	"state",
 	"county",
@@ -782,7 +782,7 @@ _geocode_parse_search_json (const char *contents,
 	const GError *err = NULL;
 	int num_places, i;
 	GNode *place_tree;
-	char *s_array[N_ATTRS];
+	char *s_array[G_N_ELEMENTS (attributes)];
 
 	ret = NULL;
 
