@@ -95,15 +95,21 @@ GeocodeReverse *
 geocode_reverse_new_for_location (GeocodeLocation *location)
 {
 	GeocodeReverse *object;
+	char coord[G_ASCII_DTOSTR_BUF_SIZE];
+	char *lat;
+	char *lon;
 
+	lat = g_strdup (g_ascii_dtostr (coord,
+	                                G_ASCII_DTOSTR_BUF_SIZE,
+	                                geocode_location_get_latitude (location)));
+
+	lon = g_strdup (g_ascii_dtostr (coord,
+	                                G_ASCII_DTOSTR_BUF_SIZE,
+	                                geocode_location_get_longitude (location)));
 	object = g_object_new (GEOCODE_TYPE_REVERSE, NULL);
 
-	g_hash_table_insert (object->priv->ht,
-			     g_strdup ("lat"),
-			     g_strdup_printf ("%g",  geocode_location_get_latitude (location)));
-	g_hash_table_insert (object->priv->ht,
-			     g_strdup ("lon"),
-			     g_strdup_printf ("%g",  geocode_location_get_longitude (location)));
+	g_hash_table_insert (object->priv->ht, g_strdup ("lat"), lat);
+	g_hash_table_insert (object->priv->ht, g_strdup ("lon"), lon);
 
 	return object;
 }
@@ -215,7 +221,8 @@ on_query_data_loaded (SoupSession *session,
 	GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (user_data);
 	GError *error = NULL;
 	char *contents;
-	gpointer ret;
+	GeocodePlace *ret;
+	GHashTable *attributes;
 
         if (query->status_code != SOUP_STATUS_OK) {
 		g_set_error_literal (&error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -227,9 +234,9 @@ on_query_data_loaded (SoupSession *session,
 	}
 
         contents = g_strndup (query->response_body->data, query->response_body->length);
-	ret = resolve_json (contents, &error);
+	attributes = resolve_json (contents, &error);
 
-	if (ret == NULL) {
+	if (attributes == NULL) {
 		g_simple_async_result_take_error (simple, error);
 		g_simple_async_result_complete_in_idle (simple);
 		g_object_unref (simple);
@@ -241,7 +248,10 @@ on_query_data_loaded (SoupSession *session,
 	_geocode_glib_cache_save (query, contents);
 	g_free (contents);
 
+        ret = _geocode_create_place_from_attributes (attributes);
+        g_hash_table_destroy (attributes);
 	g_simple_async_result_set_op_res_gpointer (simple, ret, NULL);
+
 	g_simple_async_result_complete_in_idle (simple);
 	g_object_unref (simple);
 }
@@ -362,10 +372,10 @@ get_resolve_query_for_params (GHashTable  *orig_ht)
  * geocode_reverse_resolve_finish() to get the result of the operation.
  **/
 void
-geocode_reverse_resolve_async (GeocodeReverse       *object,
-			       GCancellable        *cancellable,
-			       GAsyncReadyCallback  callback,
-			       gpointer             user_data)
+geocode_reverse_resolve_async (GeocodeReverse     *object,
+			       GCancellable       *cancellable,
+			       GAsyncReadyCallback callback,
+			       gpointer            user_data)
 {
 	GSimpleAsyncResult *simple;
 	SoupMessage *query;
@@ -411,9 +421,9 @@ geocode_reverse_resolve_async (GeocodeReverse       *object,
  * errors. Free the returned instance with #g_object_unref() when done.
  **/
 GeocodePlace *
-geocode_reverse_resolve_finish (GeocodeReverse      *object,
-				GAsyncResult        *res,
-				GError             **error)
+geocode_reverse_resolve_finish (GeocodeReverse *object,
+				GAsyncResult   *res,
+				GError        **error)
 {
 	GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (res);
 
@@ -439,8 +449,8 @@ geocode_reverse_resolve_finish (GeocodeReverse      *object,
  * errors. Free the returned instance with #g_object_unref() when done.
  **/
 GeocodePlace *
-geocode_reverse_resolve (GeocodeReverse      *object,
-			 GError             **error)
+geocode_reverse_resolve (GeocodeReverse *object,
+			 GError        **error)
 {
 	SoupMessage *query;
 	char *contents;
